/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQtChart.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtChart.h"

#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractbarseries.sip"
#include <qabstractbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qarealegendmarker.sip"
#include <qarealegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qareaseries.sip"
#include <qareaseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarcategoryaxis.sip"
#include <qbarcategoryaxis.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarlegendmarker.sip"
#include <qbarlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarseries.sip"
#include <qbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarset.sip"
#include <qbarset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotlegendmarker.sip"
#include <qboxplotlegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotseries.sip"
#include <qboxplotseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxset.sip"
#include <qboxset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlesticklegendmarker.sip"
#include <qcandlesticklegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickmodelmapper.sip"
#include <qcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickseries.sip"
#include <qcandlestickseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickset.sip"
#include <qcandlestickset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcategoryaxis.sip"
#include <qcategoryaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchart.sip"
#include <qchart.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchartview.sip"
#include <qchartview.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qdatetimeaxis.sip"
#include <qdatetimeaxis.h>
#line 34 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qdatetimeaxis.sip"
#include <qdatetimeaxis.h>
#line 69 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQDateTimeAxis.cpp"

#line 28 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobject.sip"
#include <qobject.h>
#line 73 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQDateTimeAxis.cpp"
#line 27 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qstring.sip"
#include <qstring.h>
#line 76 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQDateTimeAxis.cpp"
#line 360 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qdatetime.sip"
#include <qdatetime.h>
#line 79 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQDateTimeAxis.cpp"
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 32 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 84 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQDateTimeAxis.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qcolor.sip"
#include <qcolor.h>
#line 87 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQDateTimeAxis.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qpen.sip"
#include <qpen.h>
#line 90 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQDateTimeAxis.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qbrush.sip"
#include <qbrush.h>
#line 93 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQDateTimeAxis.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qfont.sip"
#include <qfont.h>
#line 96 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQDateTimeAxis.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 99 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQDateTimeAxis.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 102 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQDateTimeAxis.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 107 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQDateTimeAxis.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 110 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQDateTimeAxis.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 113 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQDateTimeAxis.cpp"
#line 252 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 116 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQDateTimeAxis.cpp"
#line 240 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 119 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQDateTimeAxis.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qvariant.sip"
#include <qvariant.h>
#line 122 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQDateTimeAxis.cpp"
#line 38 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 125 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQDateTimeAxis.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 128 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQDateTimeAxis.cpp"
#line 149 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 131 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQDateTimeAxis.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qthread.sip"
#include <qthread.h>
#line 134 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQDateTimeAxis.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 137 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQDateTimeAxis.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregexp.sip"
#include <qregexp.h>
#line 140 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQDateTimeAxis.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 143 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQDateTimeAxis.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQDateTimeAxis.cpp"


class sipQtCharts_QDateTimeAxis : public ::QtCharts::QDateTimeAxis
{
public:
    sipQtCharts_QDateTimeAxis(::QObject*);
    virtual ~sipQtCharts_QDateTimeAxis();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    ::QtCharts::QAbstractAxis::AxisType type() const SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQtCharts_QDateTimeAxis(const sipQtCharts_QDateTimeAxis &);
    sipQtCharts_QDateTimeAxis &operator = (const sipQtCharts_QDateTimeAxis &);

    char sipPyMethods[8];
};

sipQtCharts_QDateTimeAxis::sipQtCharts_QDateTimeAxis(::QObject*a0): ::QtCharts::QDateTimeAxis(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQtCharts_QDateTimeAxis::~sipQtCharts_QDateTimeAxis()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQtCharts_QDateTimeAxis::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtChart_qt_metaobject(sipPySelf, sipType_QtCharts_QDateTimeAxis);

    return ::QtCharts::QDateTimeAxis::metaObject();
}

int sipQtCharts_QDateTimeAxis::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QtCharts::QDateTimeAxis::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtChart_qt_metacall(sipPySelf, sipType_QtCharts_QDateTimeAxis, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQtCharts_QDateTimeAxis::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtChart_qt_metacast(sipPySelf, sipType_QtCharts_QDateTimeAxis, _clname, &sipCpp) ? sipCpp : ::QtCharts::QDateTimeAxis::qt_metacast(_clname));
}

void sipQtCharts_QDateTimeAxis::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QtCharts::QDateTimeAxis::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtChart_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtChart_0(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtCharts_QDateTimeAxis::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QtCharts::QDateTimeAxis::connectNotify(a0);
        return;
    }

    extern void sipVH_QtChart_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtChart_0(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtCharts_QDateTimeAxis::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QtCharts::QDateTimeAxis::customEvent(a0);
        return;
    }

    extern void sipVH_QtChart_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtChart_1(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtCharts_QDateTimeAxis::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QtCharts::QDateTimeAxis::childEvent(a0);
        return;
    }

    extern void sipVH_QtChart_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtChart_2(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtCharts_QDateTimeAxis::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QtCharts::QDateTimeAxis::timerEvent(a0);
        return;
    }

    extern void sipVH_QtChart_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtChart_3(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQtCharts_QDateTimeAxis::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QtCharts::QDateTimeAxis::eventFilter(a0, a1);

    extern bool sipVH_QtChart_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtChart_4(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQtCharts_QDateTimeAxis::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QtCharts::QDateTimeAxis::event(a0);

    extern bool sipVH_QtChart_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtChart_5(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QtCharts::QAbstractAxis::AxisType sipQtCharts_QDateTimeAxis::type() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[7]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_type);

    if (!sipMeth)
        return ::QtCharts::QDateTimeAxis::type();

    extern ::QtCharts::QAbstractAxis::AxisType sipVH_QtChart_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtChart_6(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}


PyDoc_STRVAR(doc_QtCharts_QDateTimeAxis_type, "type(self) -> QAbstractAxis.AxisType");

extern "C" {static PyObject *meth_QtCharts_QDateTimeAxis_type(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QDateTimeAxis_type(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QtCharts::QDateTimeAxis *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QDateTimeAxis, &sipCpp))
        {
            ::QtCharts::QAbstractAxis::AxisType sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QtCharts::QDateTimeAxis::type() : sipCpp->type());

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QtCharts_QAbstractAxis_AxisType);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDateTimeAxis, sipName_type, doc_QtCharts_QDateTimeAxis_type);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QDateTimeAxis_setMin, "setMin(self, min: QDateTime|datetime.datetime)");

extern "C" {static PyObject *meth_QtCharts_QDateTimeAxis_setMin(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QDateTimeAxis_setMin(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QDateTime* a0;
        int a0State = 0;
        ::QtCharts::QDateTimeAxis *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtCharts_QDateTimeAxis, &sipCpp, sipType_QDateTime, &a0, &a0State))
        {
            sipCpp->setMin(*a0);
            sipReleaseType(a0, sipType_QDateTime, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QDateTimeAxis, sipName_setMin, doc_QtCharts_QDateTimeAxis_setMin);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QDateTimeAxis_min, "min(self) -> QDateTime");

extern "C" {static PyObject *meth_QtCharts_QDateTimeAxis_min(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QDateTimeAxis_min(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QDateTimeAxis *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QDateTimeAxis, &sipCpp))
        {
            ::QDateTime*sipRes;

            sipRes = new ::QDateTime(sipCpp->min());

            return sipConvertFromNewType(sipRes, sipType_QDateTime, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDateTimeAxis, sipName_min, doc_QtCharts_QDateTimeAxis_min);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QDateTimeAxis_setMax, "setMax(self, max: QDateTime|datetime.datetime)");

extern "C" {static PyObject *meth_QtCharts_QDateTimeAxis_setMax(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QDateTimeAxis_setMax(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QDateTime* a0;
        int a0State = 0;
        ::QtCharts::QDateTimeAxis *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtCharts_QDateTimeAxis, &sipCpp, sipType_QDateTime, &a0, &a0State))
        {
            sipCpp->setMax(*a0);
            sipReleaseType(a0, sipType_QDateTime, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QDateTimeAxis, sipName_setMax, doc_QtCharts_QDateTimeAxis_setMax);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QDateTimeAxis_max, "max(self) -> QDateTime");

extern "C" {static PyObject *meth_QtCharts_QDateTimeAxis_max(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QDateTimeAxis_max(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QDateTimeAxis *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QDateTimeAxis, &sipCpp))
        {
            ::QDateTime*sipRes;

            sipRes = new ::QDateTime(sipCpp->max());

            return sipConvertFromNewType(sipRes, sipType_QDateTime, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDateTimeAxis, sipName_max, doc_QtCharts_QDateTimeAxis_max);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QDateTimeAxis_setRange, "setRange(self, min: QDateTime|datetime.datetime, max: QDateTime|datetime.datetime)");

extern "C" {static PyObject *meth_QtCharts_QDateTimeAxis_setRange(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QDateTimeAxis_setRange(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QDateTime* a0;
        int a0State = 0;
        ::QDateTime* a1;
        int a1State = 0;
        ::QtCharts::QDateTimeAxis *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1J1", &sipSelf, sipType_QtCharts_QDateTimeAxis, &sipCpp, sipType_QDateTime, &a0, &a0State, sipType_QDateTime, &a1, &a1State))
        {
            sipCpp->setRange(*a0, *a1);
            sipReleaseType(a0, sipType_QDateTime, a0State);
            sipReleaseType(a1, sipType_QDateTime, a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QDateTimeAxis, sipName_setRange, doc_QtCharts_QDateTimeAxis_setRange);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QDateTimeAxis_setFormat, "setFormat(self, format: str|None)");

extern "C" {static PyObject *meth_QtCharts_QDateTimeAxis_setFormat(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QDateTimeAxis_setFormat(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QString* a0;
        int a0State = 0;
        ::QtCharts::QDateTimeAxis *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtCharts_QDateTimeAxis, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setFormat(*a0);
            sipReleaseType(a0, sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QDateTimeAxis, sipName_setFormat, doc_QtCharts_QDateTimeAxis_setFormat);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QDateTimeAxis_format, "format(self) -> str");

extern "C" {static PyObject *meth_QtCharts_QDateTimeAxis_format(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QDateTimeAxis_format(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QDateTimeAxis *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QDateTimeAxis, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->format());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDateTimeAxis, sipName_format, doc_QtCharts_QDateTimeAxis_format);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QDateTimeAxis_setTickCount, "setTickCount(self, count: int)");

extern "C" {static PyObject *meth_QtCharts_QDateTimeAxis_setTickCount(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QDateTimeAxis_setTickCount(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QtCharts::QDateTimeAxis *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QtCharts_QDateTimeAxis, &sipCpp, &a0))
        {
            sipCpp->setTickCount(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QDateTimeAxis, sipName_setTickCount, doc_QtCharts_QDateTimeAxis_setTickCount);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QDateTimeAxis_tickCount, "tickCount(self) -> int");

extern "C" {static PyObject *meth_QtCharts_QDateTimeAxis_tickCount(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QDateTimeAxis_tickCount(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QDateTimeAxis *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QDateTimeAxis, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->tickCount();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDateTimeAxis, sipName_tickCount, doc_QtCharts_QDateTimeAxis_tickCount);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QtCharts_QDateTimeAxis(void *, const sipTypeDef *);}
static void *cast_QtCharts_QDateTimeAxis(void *sipCppV, const sipTypeDef *targetType)
{
    ::QtCharts::QDateTimeAxis *sipCpp = reinterpret_cast< ::QtCharts::QDateTimeAxis *>(sipCppV);

    if (targetType == sipType_QtCharts_QDateTimeAxis)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QtCharts_QAbstractAxis)->ctd_cast(static_cast< ::QtCharts::QAbstractAxis *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QtCharts_QDateTimeAxis(void *, int);}
static void release_QtCharts_QDateTimeAxis(void *sipCppV, int)
{
    ::QtCharts::QDateTimeAxis *sipCpp = reinterpret_cast< ::QtCharts::QDateTimeAxis *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QtCharts_QDateTimeAxis(Py_ssize_t);}
static void *array_QtCharts_QDateTimeAxis(Py_ssize_t sipNrElem)
{
    return new ::QtCharts::QDateTimeAxis[sipNrElem];
}


extern "C" {static void array_delete_QtCharts_QDateTimeAxis(void *);}
static void array_delete_QtCharts_QDateTimeAxis(void *sipCpp)
{
    delete[] reinterpret_cast< ::QtCharts::QDateTimeAxis *>(sipCpp);
}


extern "C" {static void dealloc_QtCharts_QDateTimeAxis(sipSimpleWrapper *);}
static void dealloc_QtCharts_QDateTimeAxis(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQtCharts_QDateTimeAxis *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QtCharts_QDateTimeAxis(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QtCharts_QDateTimeAxis(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QtCharts_QDateTimeAxis(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQtCharts_QDateTimeAxis *sipCpp = SIP_NULLPTR;

    {
        ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQtCharts_QDateTimeAxis(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QtCharts_QDateTimeAxis[] = {{8, 255, 1}};


static PyMethodDef methods_QtCharts_QDateTimeAxis[] = {
    {sipName_format, meth_QtCharts_QDateTimeAxis_format, METH_VARARGS, doc_QtCharts_QDateTimeAxis_format},
    {sipName_max, meth_QtCharts_QDateTimeAxis_max, METH_VARARGS, doc_QtCharts_QDateTimeAxis_max},
    {sipName_min, meth_QtCharts_QDateTimeAxis_min, METH_VARARGS, doc_QtCharts_QDateTimeAxis_min},
    {sipName_setFormat, meth_QtCharts_QDateTimeAxis_setFormat, METH_VARARGS, doc_QtCharts_QDateTimeAxis_setFormat},
    {sipName_setMax, meth_QtCharts_QDateTimeAxis_setMax, METH_VARARGS, doc_QtCharts_QDateTimeAxis_setMax},
    {sipName_setMin, meth_QtCharts_QDateTimeAxis_setMin, METH_VARARGS, doc_QtCharts_QDateTimeAxis_setMin},
    {sipName_setRange, meth_QtCharts_QDateTimeAxis_setRange, METH_VARARGS, doc_QtCharts_QDateTimeAxis_setRange},
    {sipName_setTickCount, meth_QtCharts_QDateTimeAxis_setTickCount, METH_VARARGS, doc_QtCharts_QDateTimeAxis_setTickCount},
    {sipName_tickCount, meth_QtCharts_QDateTimeAxis_tickCount, METH_VARARGS, doc_QtCharts_QDateTimeAxis_tickCount},
    {sipName_type, meth_QtCharts_QDateTimeAxis_type, METH_VARARGS, doc_QtCharts_QDateTimeAxis_type}
};

PyDoc_STRVAR(doc_QtCharts_QDateTimeAxis, "\1QDateTimeAxis(parent: QObject|None = None)");


/* Define this type's signals. */
static const pyqt5QtSignal signals_QtCharts_QDateTimeAxis[] = {
    {"tickCountChanged(int)", "\1tickCountChanged(self, tick: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"formatChanged(QString)", "\1formatChanged(self, format: str|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"rangeChanged(QDateTime,QDateTime)", "\1rangeChanged(self, min: QDateTime|datetime.datetime, max: QDateTime|datetime.datetime)", SIP_NULLPTR, SIP_NULLPTR},
    {"maxChanged(QDateTime)", "\1maxChanged(self, max: QDateTime|datetime.datetime)", SIP_NULLPTR, SIP_NULLPTR},
    {"minChanged(QDateTime)", "\1minChanged(self, min: QDateTime|datetime.datetime)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QtCharts_QDateTimeAxis = {
    &::QtCharts::QDateTimeAxis::staticMetaObject,
    0,
    signals_QtCharts_QDateTimeAxis,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtChart_QtCharts_QDateTimeAxis = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QtCharts__QDateTimeAxis,
        SIP_NULLPTR,
        &plugin_QtCharts_QDateTimeAxis,
    },
    {
        sipNameNr_QDateTimeAxis,
        {0, 0, 1},
        10, methods_QtCharts_QDateTimeAxis,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QtCharts_QDateTimeAxis,
    -1,
    -1,
    supers_QtCharts_QDateTimeAxis,
    SIP_NULLPTR,
    init_type_QtCharts_QDateTimeAxis,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QtCharts_QDateTimeAxis,
    SIP_NULLPTR,
    array_QtCharts_QDateTimeAxis,
    SIP_NULLPTR,
    release_QtCharts_QDateTimeAxis,
    cast_QtCharts_QDateTimeAxis,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QtCharts_QDateTimeAxis,
    sizeof (::QtCharts::QDateTimeAxis),
};
